--creating tables
CREATE TABLE [dbo].[hdCategories] (
	[CategoryID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] [varchar] (50) NOT NULL,
	[SectionID] int NULL
)
GO

CREATE TABLE [dbo].[hdSections] (
	[SectionID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] [varchar] (50) NOT NULL
)
GO

CREATE TABLE [dbo].[hdCategoryPermissions] (
	[UserID] [int] NOT NULL ,
	[CategoryID] [int] NOT NULL 
)
GO
--now add complex primary key in [hdCategoryPermissions] table
ALTER TABLE [dbo].[hdCategoryPermissions] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCategoryPermissions] PRIMARY KEY CLUSTERED 
	(
		[UserID],
		[CategoryID]
	)
GO

CREATE TABLE [dbo].[hdComments] (
	[CommentID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[IssueID] [int] NOT NULL ,
	[CommentDate] [datetime] NOT NULL DEFAULT (getdate()),
	[UserID] [int] NULL ,
	[Body] [varchar] (4000) NOT NULL 
)
GO

CREATE TABLE [dbo].[hdIssues] (
	[IssueID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[IssueDate] [datetime] NOT NULL DEFAULT (getdate()),
	[UserID] [int] NOT NULL ,
	[CategoryID] [int] NOT NULL ,
	[ResolvedDate] [datetime] NULL ,
	[AssignedToUserID] [int] NULL ,
	[Subject] [varchar] (100) NOT NULL ,
	[Body] [varchar] (4000) NOT NULL ,
	[UpdatedByUser] [bit] NOT NULL DEFAULT (0),
	[UpdatedByPerformer] [bit] NOT NULL DEFAULT (0),
	[StatusID] [int] NOT NULL DEFAULT (1),
	[PublishToKB] [bit] NOT NULL DEFAULT (0),
	[Priority] smallint NOT NULL DEFAULT (0)
)
GO

CREATE TABLE [dbo].[hdSettings] (
	[EmailNotificationsEnabled] [bit] NOT NULL DEFAULT (0),
	[SMTPServer] [varchar] (50) NULL ,
	[SMTPAuthRequired] [bit] NOT NULL  DEFAULT (0),
	[SMTPUserName] [varchar] (50) NULL ,
	[SMTPPassword] [varchar] (50) NULL ,
	[SMTPUseSSL] [bit] NOT NULL  DEFAULT (0) ,
	[FromAddress] [varchar] (50) NULL ,
	AllowUserRegistration bit NOT NULL  DEFAULT (1),
	SMTPPort int NOT NULL DEFAULT (25),
	MailCheckerEnabled bit NOT NULL DEFAULT (0),
	MailCheckerInterval int NOT NULL DEFAULT (600),
	MailCheckerPOPServer [varchar] (50) NULL,
	MailCheckerPOPPort int NOT NULL DEFAULT (110),
	MailCheckerPOPLogin [varchar] (50) NULL,
	MailCheckerPOPPassword [varchar] (50) NULL,
	MailCheckerUseSSL bit NOT NULL DEFAULT (0),
	MailCheckerNewIssuesCategoryID int NOT NULL DEFAULT (1),
	MailCheckerAllowUnregisteredUsers bit NOT NULL DEFAULT (0),
	RestrictIssueDeletion bit NOT NULL DEFAULT (0),
	Lang [varchar] (10) NOT NULL DEFAULT ('en-US'),
	MaxAttachSize int NOT NULL DEFAULT (1000),
	EmailTemplate varchar (2000) NOT NULL DEFAULT '',
	RestrictIssueClosing bit NOT NULL DEFAULT (0)
)
GO

CREATE TABLE [dbo].[hdStatus] (
	[StatusID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] [varchar] (50) NOT NULL 
)
GO

CREATE TABLE [dbo].[hdUsers] (
	[UserID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[UserName] [varchar] (50) NOT NULL ,
	[email] [varchar] (50) NOT NULL ,
	[Password] [varchar] (20) NOT NULL ,
	[IsAdministrator] [bit] NOT NULL DEFAULT (0),
	[FirstName] varchar(255) NOT NULL DEFAULT (''),
	[LastName] varchar(255) NOT NULL DEFAULT (''),
	[Notes] varchar(4000) NOT NULL DEFAULT ('')
)
GO
--now add constraint - unique username - in hdUsers table
ALTER TABLE [dbo].[hdUsers] WITH NOCHECK ADD 
	CONSTRAINT [IX_hdUsers_UniqueName] UNIQUE  NONCLUSTERED 
	(
		[username]
	)
GO

CREATE TABLE [dbo].[hdFileAttachments](
		[FileID] [int] IDENTITY(1,1) NOT NULL PRIMARY KEY,
		[IssueID] [int] NOT NULL,
		[UserID] [int] NOT NULL,
		[FileName] [varchar](255) NOT NULL,
		[FileData] [image] NOT NULL
)


--creating foreign keys
ALTER TABLE [dbo].[hdCategoryPermissions] ADD 
	CONSTRAINT [FK_hdCategoryPermissions_hdCategories] FOREIGN KEY 
	(
		[CategoryID]
	) REFERENCES [dbo].[hdCategories] (
		[CategoryID]
	),
	CONSTRAINT [FK_hdCategoryPermissions_hdUsers] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[hdUsers] (
		[UserID]
	)
GO

ALTER TABLE [dbo].[hdComments] ADD 
	CONSTRAINT [FK_hdComments_hdIssues] FOREIGN KEY 
	(
		[IssueID]
	) REFERENCES [dbo].[hdIssues] (
		[IssueID]
	),
	CONSTRAINT [FK_hdComments_hdUsers] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[hdUsers] (
		[UserID]
	)
GO

ALTER TABLE [dbo].[hdIssues] ADD 
	CONSTRAINT [FK_hdIssues_hdCategories] FOREIGN KEY 
	(
		[CategoryID]
	) REFERENCES [dbo].[hdCategories] (
		[CategoryID]
	),
	CONSTRAINT [FK_hdIssues_hdStatus] FOREIGN KEY 
	(
		[StatusID]
	) REFERENCES [dbo].[hdStatus] (
		[StatusID]
	),
	CONSTRAINT [FK_hdIssues_hdUsers1] FOREIGN KEY 
	(
		[UserID]
	) REFERENCES [dbo].[hdUsers] (
		[UserID]
	),
	CONSTRAINT [FK_hdIssues_hdUsers3] FOREIGN KEY 
	(
		[AssignedToUserID]
	) REFERENCES [dbo].[hdUsers] (
		[UserID]
	)
GO

ALTER TABLE [dbo].[hdFileAttachments] ADD
	CONSTRAINT [FK_hdFileAttachments_hdIssues] FOREIGN KEY
	(
		[IssueID]
	) REFERENCES [dbo].[hdIssues] (
		[IssueID]
	),
	CONSTRAINT [FK_hdFileAttachments_hdUsers] FOREIGN KEY
	(
		[UserID]
	)
	REFERENCES [dbo].[hdUsers] (
		[UserID]
	)
GO

--create TWO PRE-DEFINED USERS
INSERT INTO hdUsers (username, email, password, IsAdministrator)
VALUES ('admin', 'admin@testmail', 'admin', 1)
GO

INSERT INTO hdUsers (username, email, password, IsAdministrator)
VALUES ('client', 'client@testmail', 'client', 0)
GO

--create pre-defined sections
INSERT INTO hdSections (Name) VALUES ('Sales')
go

INSERT INTO hdSections (Name) VALUES ('Tech')
go

--create PRE-DEFINED CATEGORIES
INSERT INTO hdCategories (Name, SectionID) VALUES ('Sales (sample category)', 1)
go

INSERT INTO hdCategories (Name, SectionID) VALUES ('Hardware (sample category)', 2)
go

INSERT INTO hdCategories (Name, SectionID) VALUES ('Software (sample category)', 2)
go

--create default STATUSes DO NOT REMOVE!!!!!!!!!!!!!!!!
INSERT INTO hdStatus (Name) VALUES ('New')
go

INSERT INTO hdStatus (Name) VALUES ('In progress')
go

INSERT INTO hdStatus (Name) VALUES ('Resolved')
go